
#ifndef _C12_et552_
#define _C12_et552_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1451_13530(EIF_REFERENCE);
extern EIF_BOOLEAN F1451_13531(EIF_REFERENCE);
extern EIF_REFERENCE F1451_13533(EIF_REFERENCE);
extern void EIF_Minit552(void);

#ifdef __cplusplus
}
#endif

#endif
